@@ -1,26 +1,15 @@
-######################################################################
-# neqtl.R
-#
-# Karl W Broman
-# Ported from http://github.com/kbroman/neqtl on 27 apr 2012
-#
-#     This program is free software; you can redistribute it and/or
-#     modify it under the terms of the GNU General Public License,
-#     version 3, as published by the Free Software Foundation.
-# 
-#     This program is distributed in the hope that it will be useful,
-#     but without any warranty; without even the implied warranty of
-#     merchantability or fitness for a particular purpose.  See the GNU
-#     General Public License, version 3, for more details.
-# 
-#     A copy of the GNU General Public License, version 3, is available
-#     at http://www.r-project.org/Licenses/GPL-3
-#
-# Contains: neqtl, smoothall, smoothchr
-######################################################################
-
-neqtl <- function(sigpos.out,chr,pos,win=5)
-     smoothall(sigpos.out,chr,pos,window=win)
+#' neqtl.R Ported from http://github.com/kbroman/neqtl
+#'
+#' @param sigpos.out position(s) of max
+#' @param chr chromosome as character
+#' @param pos position on chromosome
+#' @param win window width in cM
+#'
+#' @export
+#' @importFrom broman runningmean
+neqtl <- function(sigpos.out,chr,pos,win=5) {
+  smoothall(sigpos.out,chr,pos,window=win)
+}
 
 smoothall <- function(themax, thechr, thepos, window=5)
 {
@@ -53,7 +42,7 @@ smoothchr <- function(themax, thepos, window=5)
   o <- order(temploc)
   temploc <- temploc[o]
   tempval <- tempval[o]
-  smoothed <- runningmean(temploc, tempval, at=thepos, window=window, what="sum")
+  smoothed <- broman::runningmean(temploc, tempval, at=thepos, window=window, what="sum")
   ## NB: This differs from R/neqtl, where at=theloc.
   cbind(thepos, smoothed)
 }
